@@ -3,6 +3,7 @@ use strict;
 use warnings;
 use App::cpm::version;
 use App::cpm::Logger;
+use CPAN::DistnameInfo;
 
 sub new {
     my ($class, %option) = @_;
@@ -26,6 +27,13 @@ for my $attr (qw(
     };
 }
 
+sub distvname {
+    my $self = shift;
+    $self->{distvname} ||= do {
+        CPAN::DistnameInfo->new($self->distfile)->distvname || $self->distfile;
+    };
+}
+
 sub append_provide {
     my ($self, $provide) = @_;
     return if $self->providing($provide->{package});
